@@ -11,6 +11,11 @@ class Eos:
         self.key_provider = config[
             'key_provider'] if 'key_provider' in config else '5KQwrPbwdL6PhXujxW37FSSQZ1JiwsST4cqQzDeyXtP79zkvFD3'
 
+        if 'debug' in config:
+            self.debug_mode = config['debug']
+        else:
+            self.debug_mode = False
+
     @classmethod
     def generate_key_pair(cls):
         response = muterun_js(cls.current_dir + '/js/GenerateKeys.js')
@@ -104,5 +109,6 @@ class Eos:
 
 def load_data(stdout):
     true_string = stdout.decode('utf8')
-    print(true_string)
+    if self.debug_mode:
+        print(true_string)
     return json.loads(true_string)
